==> esp8266-0.5.0.crate: esp8266-0.5.0/src/slc/slc_tx_link.rs <==
#[doc = "Register `SLC_TX_LINK` reader"]
pub struct R(crate::R<SLC_TX_LINK_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SLC_TX_LINK_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SLC_TX_LINK_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SLC_TX_LINK_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SLC_TX_LINK` writer"]
pub struct W(crate::W<SLC_TX_LINK_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SLC_TX_LINK_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SLC_TX_LINK_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SLC_TX_LINK_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SLC_TXLINK_PARK` reader - "]
pub struct SLC_TXLINK_PARK_R(crate::FieldReader<bool, bool>);
impl SLC_TXLINK_PARK_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TXLINK_PARK_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXLINK_PARK_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXLINK_PARK` writer - "]
pub struct SLC_TXLINK_PARK_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXLINK_PARK_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
        self.w
    }
}
#[doc = "Field `SLC_TXLINK_RESTART` reader - "]
pub struct SLC_TXLINK_RESTART_R(crate::FieldReader<bool, bool>);
impl SLC_TXLINK_RESTART_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TXLINK_RESTART_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXLINK_RESTART_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXLINK_RESTART` writer - "]
pub struct SLC_TXLINK_RESTART_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXLINK_RESTART_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
        self.w
    }
}
#[doc = "Field `SLC_TXLINK_START` reader - "]
pub struct SLC_TXLINK_START_R(crate::FieldReader<bool, bool>);
impl SLC_TXLINK_START_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TXLINK_START_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXLINK_START_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXLINK_START` writer - "]
pub struct SLC_TXLINK_START_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXLINK_START_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
        self.w
    }
}
#[doc = "Field `SLC_TXLINK_STOP` reader - "]
pub struct SLC_TXLINK_STOP_R(crate::FieldReader<bool, bool>);
impl SLC_TXLINK_STOP_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TXLINK_STOP_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXLINK_STOP_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXLINK_STOP` writer - "]
pub struct SLC_TXLINK_STOP_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXLINK_STOP_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
        self.w
    }
}
#[doc = "Field `SLC_TXLINK_ADDR` reader - "]
pub struct SLC_TXLINK_ADDR_R(crate::FieldReader<u32, u32>);
impl SLC_TXLINK_ADDR_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        SLC_TXLINK_ADDR_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXLINK_ADDR_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXLINK_ADDR` writer - "]
pub struct SLC_TXLINK_ADDR_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXLINK_ADDR_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x000f_ffff) | (value as u32 & 0x000f_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bit 31"]
    #[inline(always)]
    pub fn slc_txlink_park(&self) -> SLC_TXLINK_PARK_R {
        SLC_TXLINK_PARK_R::new(((self.bits >> 31) & 0x01) != 0)
    }
    #[doc = "Bit 30"]
    #[inline(always)]
    pub fn slc_txlink_restart(&self) -> SLC_TXLINK_RESTART_R {
        SLC_TXLINK_RESTART_R::new(((self.bits >> 30) & 0x01) != 0)
    }
    #[doc = "Bit 29"]
    #[inline(always)]
    pub fn slc_txlink_start(&self) -> SLC_TXLINK_START_R {
        SLC_TXLINK_START_R::new(((self.bits >> 29) & 0x01) != 0)
    }
    #[doc = "Bit 28"]
    #[inline(always)]
    pub fn slc_txlink_stop(&self) -> SLC_TXLINK_STOP_R {
        SLC_TXLINK_STOP_R::new(((self.bits >> 28) & 0x01) != 0)
    }
    #[doc = "Bits 0:19"]
    #[inline(always)]
    pub fn slc_txlink_addr(&self) -> SLC_TXLINK_ADDR_R {
        SLC_TXLINK_ADDR_R::new((self.bits & 0x000f_ffff) as u32)
    }
}
impl W {
    #[doc = "Bit 31"]
    #[inline(always)]
    pub fn slc_txlink_park(&mut self) -> SLC_TXLINK_PARK_W {
        SLC_TXLINK_PARK_W { w: self }
    }
    #[doc = "Bit 30"]
    #[inline(always)]
    pub fn slc_txlink_restart(&mut self) -> SLC_TXLINK_RESTART_W {
        SLC_TXLINK_RESTART_W { w: self }
    }
    #[doc = "Bit 29"]
    #[inline(always)]
    pub fn slc_txlink_start(&mut self) -> SLC_TXLINK_START_W {
        SLC_TXLINK_START_W { w: self }
    }
    #[doc = "Bit 28"]
    #[inline(always)]
    pub fn slc_txlink_stop(&mut self) -> SLC_TXLINK_STOP_W {
        SLC_TXLINK_STOP_W { w: self }
    }
    #[doc = "Bits 0:19"]
    #[inline(always)]
    pub fn slc_txlink_addr(&mut self) -> SLC_TXLINK_ADDR_W {
        SLC_TXLINK_ADDR_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "SLC_TX_LINK\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_tx_link]
(index.html) module"]
pub struct SLC_TX_LINK_SPEC;
impl crate::RegisterSpec for SLC_TX_LINK_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [slc_tx_link::R]
(R) reader structure"]
impl crate::Readable for SLC_TX_LINK_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [slc_tx_link::W]
(W) writer structure"]
impl crate::Writable for SLC_TX_LINK_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SLC_TX_LINK to value 0"]
impl crate::Resettable for SLC_TX_LINK_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.6.0.crate: esp8266-0.6.0/src/slc/slc_tx_link.rs <==
#[doc = "Register `SLC_TX_LINK` reader"]
pub struct R(crate::R<SLC_TX_LINK_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SLC_TX_LINK_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SLC_TX_LINK_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SLC_TX_LINK_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SLC_TX_LINK` writer"]
pub struct W(crate::W<SLC_TX_LINK_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SLC_TX_LINK_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SLC_TX_LINK_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SLC_TX_LINK_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SLC_TXLINK_PARK` reader - "]
pub struct SLC_TXLINK_PARK_R(crate::FieldReader<bool, bool>);
impl SLC_TXLINK_PARK_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TXLINK_PARK_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXLINK_PARK_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXLINK_PARK` writer - "]
pub struct SLC_TXLINK_PARK_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXLINK_PARK_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
        self.w
    }
}
#[doc = "Field `SLC_TXLINK_RESTART` reader - "]
pub struct SLC_TXLINK_RESTART_R(crate::FieldReader<bool, bool>);
impl SLC_TXLINK_RESTART_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TXLINK_RESTART_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXLINK_RESTART_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXLINK_RESTART` writer - "]
pub struct SLC_TXLINK_RESTART_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXLINK_RESTART_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
        self.w
    }
}
#[doc = "Field `SLC_TXLINK_START` reader - "]
pub struct SLC_TXLINK_START_R(crate::FieldReader<bool, bool>);
impl SLC_TXLINK_START_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TXLINK_START_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXLINK_START_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXLINK_START` writer - "]
pub struct SLC_TXLINK_START_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXLINK_START_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
        self.w
    }
}
#[doc = "Field `SLC_TXLINK_STOP` reader - "]
pub struct SLC_TXLINK_STOP_R(crate::FieldReader<bool, bool>);
impl SLC_TXLINK_STOP_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TXLINK_STOP_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXLINK_STOP_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXLINK_STOP` writer - "]
pub struct SLC_TXLINK_STOP_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXLINK_STOP_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
        self.w
    }
}
#[doc = "Field `SLC_TXLINK_ADDR` reader - "]
pub struct SLC_TXLINK_ADDR_R(crate::FieldReader<u32, u32>);
impl SLC_TXLINK_ADDR_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        SLC_TXLINK_ADDR_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TXLINK_ADDR_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TXLINK_ADDR` writer - "]
pub struct SLC_TXLINK_ADDR_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TXLINK_ADDR_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x000f_ffff) | (value as u32 & 0x000f_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bit 31"]
    #[inline(always)]
    pub fn slc_txlink_park(&self) -> SLC_TXLINK_PARK_R {
        SLC_TXLINK_PARK_R::new(((self.bits >> 31) & 1) != 0)
    }
    #[doc = "Bit 30"]
    #[inline(always)]
    pub fn slc_txlink_restart(&self) -> SLC_TXLINK_RESTART_R {
        SLC_TXLINK_RESTART_R::new(((self.bits >> 30) & 1) != 0)
    }
    #[doc = "Bit 29"]
    #[inline(always)]
    pub fn slc_txlink_start(&self) -> SLC_TXLINK_START_R {
        SLC_TXLINK_START_R::new(((self.bits >> 29) & 1) != 0)
    }
    #[doc = "Bit 28"]
    #[inline(always)]
    pub fn slc_txlink_stop(&self) -> SLC_TXLINK_STOP_R {
        SLC_TXLINK_STOP_R::new(((self.bits >> 28) & 1) != 0)
    }
    #[doc = "Bits 0:19"]
    #[inline(always)]
    pub fn slc_txlink_addr(&self) -> SLC_TXLINK_ADDR_R {
        SLC_TXLINK_ADDR_R::new((self.bits & 0x000f_ffff) as u32)
    }
}
impl W {
    #[doc = "Bit 31"]
    #[inline(always)]
    pub fn slc_txlink_park(&mut self) -> SLC_TXLINK_PARK_W {
        SLC_TXLINK_PARK_W { w: self }
    }
    #[doc = "Bit 30"]
    #[inline(always)]
    pub fn slc_txlink_restart(&mut self) -> SLC_TXLINK_RESTART_W {
        SLC_TXLINK_RESTART_W { w: self }
    }
    #[doc = "Bit 29"]
    #[inline(always)]
    pub fn slc_txlink_start(&mut self) -> SLC_TXLINK_START_W {
        SLC_TXLINK_START_W { w: self }
    }
    #[doc = "Bit 28"]
    #[inline(always)]
    pub fn slc_txlink_stop(&mut self) -> SLC_TXLINK_STOP_W {
        SLC_TXLINK_STOP_W { w: self }
    }
    #[doc = "Bits 0:19"]
    #[inline(always)]
    pub fn slc_txlink_addr(&mut self) -> SLC_TXLINK_ADDR_W {
        SLC_TXLINK_ADDR_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "SLC_TX_LINK\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_tx_link]
(index.html) module"]
pub struct SLC_TX_LINK_SPEC;
impl crate::RegisterSpec for SLC_TX_LINK_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [slc_tx_link::R]
(R) reader structure"]
impl crate::Readable for SLC_TX_LINK_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [slc_tx_link::W]
(W) writer structure"]
impl crate::Writable for SLC_TX_LINK_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SLC_TX_LINK to value 0"]
impl crate::Resettable for SLC_TX_LINK_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
